using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.IO;
using System.Text;
using System.Windows.Forms;
using RealEstate.RealEstateService;

namespace RealEstate {
	public partial class MainForm : Form {
		public MainForm() {
			InitializeComponent();
		}

		void Form1_Load(object sender, EventArgs e) {
			propertyBindingSource.DataSource = Program.GetService().GetProperties();
		}

		void propertyBindingNavigatorSaveItem_Click(object sender, EventArgs e) {
			this.Validate();
			this.propertyBindingSource.EndEdit();
		}

		void propertyBindingSource_CurrentChanged(object sender, EventArgs e) {
			Property row = (Property)propertyBindingSource.Current;

			string relPath = @"..\..\..\Images\";
			string photoA = relPath+string.Format(row.Photo, 'a');
			string photoB = relPath+string.Format(row.Photo, 'b');
			string photoC = relPath+string.Format(row.Photo, 'c');
			string photoD = relPath+string.Format(row.Photo, 'd');

			SetImageSource(PropertyImageA, photoA);
			SetImageSource(PropertyImageB, photoB);
			SetImageSource(PropertyImageC, photoC);
			SetImageSource(PropertyImageD, photoD);

			PropertyImageA.Cursor = Cursors.Default;
		}

		void PropertyImage_Click(object sender, EventArgs e) {

			PictureBox img = (PictureBox)sender;

			if (img.Tag != null) {
				string mainTag = PropertyImageA.Tag.ToString();
				SetImageSource(PropertyImageA, img.Tag.ToString());
				SetImageSource(img, mainTag);
			}
		}

		void Form1_Paint(object sender, PaintEventArgs e) {
			LinearGradientBrush brush = new LinearGradientBrush(
				ClientRectangle, Color.DarkBlue, Color.LightBlue, LinearGradientMode.ForwardDiagonal);
			e.Graphics.FillRectangle(brush, ClientRectangle);
		}

		void SetImageSource(PictureBox photo, string imageFile) {
			if (File.Exists(imageFile)) {
				photo.Image = Image.FromFile(imageFile);
				photo.BorderStyle = BorderStyle.FixedSingle;
				photo.Cursor = Cursors.Hand;
				photo.Tag = imageFile;
			}
			else {
				photo.BorderStyle = BorderStyle.None;
				photo.Image = null;
				photo.Tag = null;
				photo.Cursor = Cursors.Default;
			}

			if (photo == PropertyImageA)
				photo.Cursor = Cursors.Default;
		}

		private void ScheduleLink_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e) {

			using (Scheduler scheduler = new Scheduler((Property)propertyBindingSource.Current)) {
				scheduler.ShowDialog();
			}
		}
	}
}