using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Text;
using System.Windows.Forms;
using RealEstate.RealEstateService;

namespace RealEstate {
	public partial class Scheduler : Form {
		Property _property;
		PropertyShowing _showing;

		private Scheduler() {
			InitializeComponent();
		}
		public Scheduler(Property property) : this() {
			_property = property;
		}

		DateTime GetScheduledDateTime(){
			DateTime dt = new DateTime(
				DatePicker.Value.Year,
				DatePicker.Value.Month,
				DatePicker.Value.Day,
				TimePicker.Value.Hour,
				TimePicker.Value.Minute,
				0);
			return dt;
		}

		public PropertyShowing Showing {
			get { return _showing; }
		}

		private void CloseForm(object sender, EventArgs e) {

			bool allowClose = false;

			if (sender == OkButton) {
				try {
					if (AgentList.SelectedIndex < 0) {
						MessageBox.Show(
							this,
							"Agent name not set",
							"Error");
						allowClose = false;
						return;
					}

					// schedule the showing
					_showing = Program.GetService().ScheduleShowing(_property.Id, AgentList.Text, GetScheduledDateTime());
					allowClose = true;
				}
				catch (System.Web.Services.Protocols.SoapException ex) {
					DateTime dt = GetScheduledDateTime();
					MessageBox.Show(this, "This property is already being shown on " + dt.ToLongDateString() + " at " + dt.ToString("h:mm tt"));
				}
			}

			if (allowClose)
				Close();
		}

		private void Scheduler_Paint(object sender, PaintEventArgs e) {

			LinearGradientBrush brush = new LinearGradientBrush(
				ClientRectangle, Color.DarkBlue, Color.LightBlue, LinearGradientMode.ForwardDiagonal);
			e.Graphics.FillRectangle(brush, ClientRectangle);
		}
	}
}